==> giada_0.11.2~dfsg.orig.tar.gz: giada-0.11.2/src/core/graphics.h <==
/* ---------------------------------------------------------------------
 *
 * Giada - Your Hardcore Loopmachine
 *
 * graphics
 *
 * ---------------------------------------------------------------------
 *
 * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
 *
 * This file is part of Giada - Your Hardcore Loopmachine.
 *
 * Giada - Your Hardcore Loopmachine is free software: you can
 * redistribute it and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * Giada - Your Hardcore Loopmachine is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Giada - Your Hardcore Loopmachine. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * ------------------------------------------------------------------ */

#ifndef GRAPHICS_H
#define GRAPHICS_H

extern const char *giada_logo_xpm[];

extern const char *loopRepeat_xpm[];
extern const char *loopBasic_xpm[];
extern const char *loopOnce_xpm[];
extern const char *loopOnceBar_xpm[];
extern const char *oneshotBasic_xpm[];
extern const char *oneshotRetrig_xpm[];
extern const char *oneshotPress_xpm[];
extern const char *oneshotEndless_xpm[];

extern const char *updirOff_xpm[];
extern const char *updirOn_xpm[];

extern const char *pause_xpm[];
extern const char *play_xpm[];

extern const char *zoomInOff_xpm[];
extern const char *zoomInOn_xpm[];
extern const char *zoomOutOff_xpm[];
extern const char *zoomOutOn_xpm[];

extern const char *scrollLeftOff_xpm[];
extern const char *scrollLeftOn_xpm[];
extern const char *scrollRightOff_xpm[];
extern const char *scrollRightOn_xpm[];

extern const char *rewindOff_xpm[];
extern const char *rewindOn_xpm[];

extern const char *recOff_xpm[];
extern const char *recOn_xpm[];

extern const char *metronomeOff_xpm[];
extern const char *metronomeOn_xpm[];

extern const char *inputRecOn_xpm[];
extern const char *inputRecOff_xpm[];

extern const char *beatsDivideOn_xpm[];
extern const char *beatsDivideOff_xpm[];
extern const char *beatsMultiplyOn_xpm[];
extern const char *beatsMultiplyOff_xpm[];

extern const char *muteOff_xpm[];
extern const char *muteOn_xpm[];

extern const char *soloOff_xpm[];
extern const char *soloOn_xpm[];

extern const char *readActionOn_xpm[];
extern const char *readActionOff_xpm[];

extern const char *channelStop_xpm[];
extern const char *channelPlay_xpm[];

#ifdef WITH_VST
extern const char *fxOff_xpm[];
extern const char *fxOn_xpm[];

extern const char *fxShiftUpOn_xpm[];
extern const char *fxShiftUpOff_xpm[];
extern const char *fxShiftDownOn_xpm[];
extern const char *fxShiftDownOff_xpm[];

extern const char *fxRemoveOff_xpm[];
extern const char *fxRemoveOn_xpm[];

extern const char *vstLogo_xpm[];
#endif

extern const char *giada_icon[];

#endif

==> giada_0.13.2~dfsg1.orig.tar.gz: giada-0.13.2/src/core/graphics.h <==
/* ---------------------------------------------------------------------
 *
 * Giada - Your Hardcore Loopmachine
 *
 * graphics
 *
 * ---------------------------------------------------------------------
 *
 * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
 *
 * This file is part of Giada - Your Hardcore Loopmachine.
 *
 * Giada - Your Hardcore Loopmachine is free software: you can
 * redistribute it and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * Giada - Your Hardcore Loopmachine is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Giada - Your Hardcore Loopmachine. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * ------------------------------------------------------------------ */

#ifndef GRAPHICS_H
#define GRAPHICS_H

extern const char *giada_logo_xpm[];

extern const char *loopRepeat_xpm[];
extern const char *loopBasic_xpm[];
extern const char *loopOnce_xpm[];
extern const char *loopOnceBar_xpm[];
extern const char *oneshotBasic_xpm[];
extern const char *oneshotRetrig_xpm[];
extern const char *oneshotPress_xpm[];
extern const char *oneshotEndless_xpm[];

extern const char *updirOff_xpm[];
extern const char *updirOn_xpm[];

extern const char *pause_xpm[];
extern const char *play_xpm[];

extern const char *zoomInOff_xpm[];
extern const char *zoomInOn_xpm[];
extern const char *zoomOutOff_xpm[];
extern const char *zoomOutOn_xpm[];

extern const char *scrollLeftOff_xpm[];
extern const char *scrollLeftOn_xpm[];
extern const char *scrollRightOff_xpm[];
extern const char *scrollRightOn_xpm[];

extern const char *rewindOff_xpm[];
extern const char *rewindOn_xpm[];

extern const char *recOff_xpm[];
extern const char *recOn_xpm[];

extern const char *metronomeOff_xpm[];
extern const char *metronomeOn_xpm[];

extern const char *inputRecOn_xpm[];
extern const char *inputRecOff_xpm[];

extern const char *inputToOutputOn_xpm[];
extern const char *inputToOutputOff_xpm[];

extern const char *divideOn_xpm[];
extern const char *divideOff_xpm[];
extern const char *multiplyOn_xpm[];
extern const char *multiplyOff_xpm[];

extern const char *muteOff_xpm[];
extern const char *muteOn_xpm[];

extern const char *soloOff_xpm[];
extern const char *soloOn_xpm[];

extern const char *armOff_xpm[];
extern const char *armOn_xpm[];

extern const char *readActionOn_xpm[];
extern const char *readActionOff_xpm[];

extern const char *channelStop_xpm[];
extern const char *channelPlay_xpm[];

#ifdef WITH_VST
extern const char *fxOff_xpm[];
extern const char *fxOn_xpm[];

extern const char *fxShiftUpOn_xpm[];
extern const char *fxShiftUpOff_xpm[];
extern const char *fxShiftDownOn_xpm[];
extern const char *fxShiftDownOff_xpm[];

extern const char *fxRemoveOff_xpm[];
extern const char *fxRemoveOn_xpm[];

extern const char *vstLogo_xpm[];
#endif

extern const char *giada_icon[];

#endif
